Index: src/bp-core/admin/css/common-rtl.css
===================================================================
--- src/bp-core/admin/css/common-rtl.css	(revision 11908)
+++ src/bp-core/admin/css/common-rtl.css	(working copy)
@@ -18,7 +18,9 @@
 	2.1 Top level menus
 	2.2 Settings - Components
 	2.3 Tools
-3.0 User's Lists
+3.0 Users
+	3.1 Users List
+	3.2 Site Notices
 4.0 Emails - Edit page
 5.0 Tools - BuddyPress
 6.0 Plugins page
@@ -569,8 +571,12 @@
 
 
 /*------------------------------------------------------------------------------
- * 3.0 User's Lists
+ * 3.0 Users
  *----------------------------------------------------------------------------*/
+
+/*
+ * 3.1 Users List
+ */
 body.site-users-php th#role,
 body.users-php th#role,
 body.users_page_bp-signups th#count_sent {
@@ -607,6 +613,93 @@
 	font-weight: 700;
 }
 
+/*
+ * 3.2 Site Notices
+ */
+.bp-new-notice-panel {
+	background: #fff;
+	border: 1px solid #e5e5e5;
+	box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
+	font-size: 13px;
+	line-height: 2.1;
+	margin: 1.5em 0 3em;
+	overflow: auto;
+	padding: 10px 25px 25px;
+	position: relative;
+}
+
+.bp-new-notice-panel label {
+	clear: both;
+	float: right;
+	margin-left: 3%;
+	width: 20%;
+}
+
+.bp-new-notice-panel input,
+.bp-new-notice-panel textarea {
+	clear: none;
+	margin-bottom: 1em;
+	width: 75%;
+}
+
+.bp-new-notice-panel input[type="text"]:after,
+.bp-new-notice-panel textarea:after {
+	clear: both;
+	content: " ";
+	display: table;
+}
+
+.bp-new-notice-panel .button-primary {
+	margin-right: 23%;
+	width: auto;
+}
+
+.bp-notice-about {
+	font-size: 1em;
+	margin-bottom: 1em;
+}
+
+.bp-new-notice {
+	margin-bottom: 1em;
+	margin-top: 0;
+}
+
+.bp-notices-list {
+	margin-bottom: 0;
+}
+
+@media screen and (max-width: 782px) {
+
+	.bp-new-notice-panel {
+		margin-bottom: 1.5em;
+	}
+
+	.bp-new-notice-panel input,
+	.bp-new-notice-panel textarea {
+		margin-right: 0;
+		width: 100%;
+	}
+
+	.bp-new-notice-panel .button-primary {
+		margin-right: 0;
+		width: auto;
+	}
+
+	.bp-new-notice-panel .button {
+		max-width: 45%;
+		word-wrap: break-word;
+	}
+
+	.bp-notice-about {
+		margin-top: 0;
+		margin-bottom: 1em;
+	}
+
+	.bp-new-notice {
+		margin-bottom: 0.5em;
+	}
+}
+
 /*------------------------------------------------------------------------------
  * 4.0 Emails - Edit Page
  *----------------------------------------------------------------------------*/
Index: src/bp-core/admin/css/common.css
===================================================================
--- src/bp-core/admin/css/common.css	(revision 11908)
+++ src/bp-core/admin/css/common.css	(working copy)
@@ -18,7 +18,9 @@
 	2.1 Top level menus
 	2.2 Settings - Components
 	2.3 Tools
-3.0 User's Lists
+3.0 Users
+	3.1 Users List
+	3.2 Site Notices
 4.0 Emails - Edit page
 5.0 Tools - BuddyPress
 6.0 Plugins page
@@ -569,8 +571,12 @@
 
 
 /*------------------------------------------------------------------------------
- * 3.0 User's Lists
+ * 3.0 Users
  *----------------------------------------------------------------------------*/
+
+/*
+ * 3.1 Users List
+ */
 body.site-users-php th#role,
 body.users-php th#role,
 body.users_page_bp-signups th#count_sent {
@@ -607,6 +613,93 @@
 	font-weight: 700;
 }
 
+/*
+ * 3.2 Site Notices
+ */
+.bp-new-notice-panel {
+	background: #fff;
+	border: 1px solid #e5e5e5;
+	box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04);
+	font-size: 13px;
+	line-height: 2.1;
+	margin: 1.5em 0 3em;
+	overflow: auto;
+	padding: 10px 25px 25px;
+	position: relative;
+}
+
+.bp-new-notice-panel label {
+	clear: both;
+	float: left;
+	margin-right: 3%;
+	width: 20%;
+}
+
+.bp-new-notice-panel input,
+.bp-new-notice-panel textarea {
+	clear: none;
+	margin-bottom: 1em;
+	width: 75%;
+}
+
+.bp-new-notice-panel input[type="text"]:after,
+.bp-new-notice-panel textarea:after {
+	clear: both;
+	content: " ";
+	display: table;
+}
+
+.bp-new-notice-panel .button-primary {
+	margin-left: 23%;
+	width: auto;
+}
+
+.bp-notice-about {
+	font-size: 1em;
+	margin-bottom: 1em;
+}
+
+.bp-new-notice {
+	margin-bottom: 1em;
+	margin-top: 0;
+}
+
+.bp-notices-list {
+	margin-bottom: 0;
+}
+
+@media screen and (max-width: 782px) {
+
+	.bp-new-notice-panel {
+		margin-bottom: 1.5em;
+	}
+
+	.bp-new-notice-panel input,
+	.bp-new-notice-panel textarea {
+		margin-left: 0;
+		width: 100%;
+	}
+
+	.bp-new-notice-panel .button-primary {
+		margin-left: 0;
+		width: auto;
+	}
+
+	.bp-new-notice-panel .button {
+		max-width: 45%;
+		word-wrap: break-word;
+	}
+
+	.bp-notice-about {
+		margin-top: 0;
+		margin-bottom: 1em;
+	}
+
+	.bp-new-notice {
+		margin-bottom: 0.5em;
+	}
+}
+
 /*------------------------------------------------------------------------------
  * 4.0 Emails - Edit Page
  *----------------------------------------------------------------------------*/
Index: src/bp-messages/classes/class-bp-messages-component.php
===================================================================
--- src/bp-messages/classes/class-bp-messages-component.php	(revision 11908)
+++ src/bp-messages/classes/class-bp-messages-component.php	(working copy)
@@ -323,7 +323,7 @@
 				$wp_admin_nav[] = array(
 					'parent'   => 'my-account-' . $this->id,
 					'id'       => 'my-account-' . $this->id . '-notices',
-					'title'    => __( 'All Member Notices', 'buddypress' ),
+					'title'    => __( 'Site Notices', 'buddypress' ),
 					'href'     => trailingslashit( $messages_link . 'notices' ),
 					'position' => 90
 				);
Index: src/bp-messages/classes/class-bp-messages-notices-admin.php
===================================================================
--- src/bp-messages/classes/class-bp-messages-notices-admin.php	(revision 11908)
+++ src/bp-messages/classes/class-bp-messages-notices-admin.php	(working copy)
@@ -36,8 +36,8 @@
 	 * @var object
 	 */
 	public $list_table = '';
-	
 
+
 	/**
      * Create a new instance or access the current instance of this class.
      *
@@ -87,7 +87,7 @@
 	}
 
 	/**
 	 * Add the 'All Member Notices' admin menu item.
 	 *
 	 * @since 3.0.0
 	 */
@@ -98,8 +98,8 @@
 		}
 
 		$this->screen_id = add_users_page(
-			_x( 'All Member Notices', 'Notices admin page title', 'buddypress' ),
-			_x( 'All Member Notices', 'Admin Users menu', 'buddypress' ),
+			_x( 'Site Notices', 'Notices admin page title', 'buddypress' ),
+			_x( 'Site Notices', 'Admin Users menu', 'buddypress' ),
 			'manage_options',
 			'bp-notices',
 			array( $this, 'admin_index' )
@@ -154,7 +154,7 @@
 				case 'delete':
 					$notice = new BP_Messages_Notice( $notice_id );
 					$success = $notice->delete();
-					break;			
+					break;
 			}
 			if ( $success ) {
 				$redirect_to = add_query_arg( 'success', 'update', $this->url );
@@ -185,41 +185,37 @@
 		<div class="wrap">
 			<?php if ( version_compare( $GLOBALS['wp_version'], '4.8', '>=' ) ) : ?>
 
-				<h1 class="wp-heading-inline"><?php echo esc_html_x( 'All Member Notices', 'Notices admin page title', 'buddypress' ); ?></h1>
-
-					<a id="add_notice" class="page-title-action" href="#"><?php esc_html_e( 'Add New Notice', 'buddypress' ); ?></a>
-
+				<h1 class="wp-heading-inline"><?php echo esc_html_x( 'Site Notices', 'Notices admin page title', 'buddypress' ); ?></h1>
 				<hr class="wp-header-end">
 
 			<?php else : ?>
 
-				<h1>
-					<?php echo esc_html_x( 'All Member Notices', 'Notices admin page title', 'buddypress' ); ?>
-					<a id="add_notice" class="add-new-h2" href="#"><?php esc_html_e( 'Add New Notice', 'buddypress' ); ?></a>
-				</h1>
+				<h1><?php echo esc_html_x( 'Site Notices', 'Notices admin page title', 'buddypress' ); ?></h1>
 
 			<?php endif; ?>
 
-			<form action=<?php echo esc_url( wp_nonce_url( $this->url, 'new-notice', 'ns-nonce' ) ); ?> method="post">
-				<table class="widefat">
-					<tr>
-						<td><label for="bp_notice_subject"><?php esc_html_e( 'Subject', 'buddypress' ); ?></label></td>
-						<td><input type="text" class="widefat" id="bp_notice_subject" name="bp_notice[subject]"/></td>
-					</tr>
-					<tr>
-						<td><label for="bp_notice_content"><?php esc_html_e( 'Content', 'buddypress' ); ?></label></td>
-						<td><textarea class="widefat" id="bp_notice_content" name="bp_notice[content]"></textarea></td>
-					</tr>
-					<tr class="submit">
-						<td>&nbsp;</td>
-						<td style="float:right">
-							<input type="reset" value="<?php esc_attr_e( 'Cancel Notice', 'buddypress' ); ?>" class="button-secondary">
-							<input type="submit" value="<?php esc_attr_e( 'Save Notice', 'buddypress' ); ?>" name="bp_notice[send]" class="button-primary">
-						</td>
-					</tr>
-				</table>
-			<form>
+			<p class="bp-notice-about"><?php esc_html_e( 'Manage notices shown at front end of your site to all logged-in users.', 'buddypress' ); ?></p>
 
+			<div class="bp-new-notice-panel">
+
+				<h2 class="bp-new-notice"><?php esc_html_e( 'Add New Notice', 'buddypress' ); ?></h2>
+
+				<form action="<?php echo esc_url( wp_nonce_url( $this->url, 'new-notice', 'ns-nonce' ) ); ?>" method="post">
+
+					<div>
+						<label for="bp_notice_subject"><?php esc_html_e( 'Subject', 'buddypress' ); ?></label>
+						<input type="text" class="bp-panel-input" id="bp_notice_subject" name="bp_notice[subject]"/>
+
+						<label for="bp_notice_content"><?php esc_html_e( 'Content', 'buddypress' ); ?></label>
+						<textarea class="bp-panel-textarea" id="bp_notice_content" name="bp_notice[content]"></textarea>
+					</div>
+
+					<input type="submit" value="<?php esc_attr_e( 'Publish Notice', 'buddypress' ); ?>" name="bp_notice[send]" class="button button-primary save alignleft">
+
+				</form>
+
+			</div>
+
 			<?php if ( isset( $_GET['success'] ) || isset( $_GET['error'] ) ) : ?>
 
 				<div id="message" class="<?php echo isset( $_GET['success'] ) ? 'updated' : 'error'; ?>">
@@ -230,7 +226,7 @@
 							if ( 'create' === $_GET['error'] ) {
 								esc_html_e( 'Notice was not created. Please try again.', 'buddypress' );
 							} else {
-								esc_html_e( 'Notice was not updated. Please try again.', 'buddypress' );							
+								esc_html_e( 'Notice was not updated. Please try again.', 'buddypress' );
 							}
 						 } else {
 							if ( 'create' === $_GET['success'] ) {
@@ -246,6 +242,8 @@
 
 			<?php endif; ?>
 
+			<h2 class="bp-notices-list"><?php esc_html_e( 'Notices List', 'buddypress' ); ?></h2>
+
 			<?php $this->list_table->display(); ?>
 
 		</div>
@@ -87,7 +87,7 @@
 
 	/**
-	 * Add the 'All Member Notices' admin menu item.
+	 * Add the 'Site Notices' admin menu item.
 	 *
 	 * @since 3.0.0
